# -*- coding: UTF-8 -*-

from qt4a.andrcontrols import *
from qt4a.qpath import QPath

from OEDWindow import OEDWindow


class QQChatPanel(OEDWindow):
    Activity = 'com.tencent.mobileqq.activity.SplashActivity'  # QQ首页界面

    def __init__(self, app, leave_time=2):
        super(QQChatPanel, self).__init__(app, leave_time=leave_time)
        self.update_locator({
            '首页': {'type': TextView, 'root': self,
                   'locator': QPath(
                       '/Text="ke.qq.com" && Visible="True" && Instance="1"')},
            '首个会话': {'type': RelativeLayout, 'root': self, 'locator': QPath('/Id="relativeItem" && Instance="1"')},
            '输入': {'type': EditText, 'root': self, 'locator': QPath('/Id="input"')},
            '发送': {'type': Button, 'root': self, 'locator': QPath('/Text="发送" && Instance="0"')}
        })

    def goto_homepage(self, url):
        self.Controls["首个会话"].click()
        time.sleep(2)
        if self.Controls["首页"].exist():
            self.Controls["首页"].click()
            time.sleep(3)
        else:
            self.Controls["输入"].send_text(url)
            self.Controls["发送"].click()
            self.Controls["首页"].click()
            time.sleep(3)



# -*- coding: UTF-8 -*-

'''跨平台Ke App类
'''

# import time
from oed_native_lib.OEDApp import OEDApp


class OEDXApp(OEDApp):
    '''跨平台App类
    '''

    def __init__(self, device, *args, **kwargs):
        self._device = device
        super(OEDXApp, self).__init__(device._device)



# -*- coding: utf-8 -*-
# @Time     ： 2020/11/24 10:32 上午
# @Author   :  haleli
import hashlib
import os
import pickle
import time

from testbase import logger
from testbase.conf import settings
from testbase.util import ThreadGroupLocal

dirname = settings.PROJECT_ROOT
cache_root_dir = os.path.join(os.path.abspath(dirname), "cache")

if not os.path.exists(cache_root_dir):
    os.makedirs(cache_root_dir)


def md5(s):
    m = hashlib.md5()
    m.update(s)
    return m.hexdigest()


def cache_key(f, *args, **kwargs):
    s = '%s-%s-%s' % (f.__name__, str(args), str(kwargs))
    return os.path.join(cache_root_dir, '%s.dump' % md5(s))


def metis_cache_key(root, text, platform, device_id, *args, **kwargs):
    s = '%s-%s-%s-%s-%s-%s' % (type(root).__name__, text, platform, device_id, str(args), str(kwargs))
    return os.path.join(cache_root_dir, '%s.dump' % md5(s))


def cache(f):
    def wrap(*args, **kwargs):
        fn = cache_key(f, *args, **kwargs)
        if os.path.exists(fn):
            logger.info('loading cache')
            with open(fn, 'rb') as fr:
                return pickle.load(fr)

        obj = f(*args, **kwargs)
        with open(fn, 'wb') as fw:
            pickle.dump(obj, fw)
        return obj

    return wrap


def metis_cache(f):
    def wrap(self, *args, **kwargs):
        cache = ThreadGroupLocal().testcase.cache
        if cache:
            text = self.text
            if settings.PLATFORM == "iOS":
                view_or_window = self._view.element
                platform = 'ios'
                device_id = self._view.element._device.udid
            else:
                view_or_window = self._view._view_or_window
                platform = 'android'
                device_id = self._view._device.device_id

            fn = metis_cache_key(view_or_window, text, platform, device_id, *args, **kwargs)
            if os.path.exists(fn):
                logger.info('loading cache')
                time0 = time.time()
                with open(fn, 'rb') as fr:
                    obj = pickle.load(fr)
                    cost = time.time() - time0
                    logger.info("使用缓存查找控件 %s 耗时 %.2f 秒" % (self.text, cost))
                    return obj
        time0 = time.time()
        obj = f(self, *args, **kwargs)
        cost = time.time() - time0
        logger.info("使用metis查找控件 %s 耗时 %.2f 秒" % (self.text, cost))
        if cache:
            with open(fn, 'wb') as fw:
                pickle.dump(obj, fw)
        return obj

    return wrap



# -*- coding: utf-8 -*-

from qt4w.webcontrols import *

'''
Ke WebPage类
'''


class OEDWebPage(WebPage):
    def __init__(self, webview_or_webpage):
        super(OEDWebPage, self).__init__(webview_or_webpage)



# -*- coding: utf-8 -*-
# @Time     ： 2020/11/12 2:26 下午
# @Author   :  haleli

'''Tencent is pleased to support the open source community by making FAutoTest available. Copyright (C) 2018 THL A29
Limited, a Tencent company. All rights reserved. Licensed under the BSD 3-Clause License (the "License"); you may not
use this file except in compliance with the License. You may obtain a copy of the License at
https://opensource.org/licenses/BSD-3-Clause Unless required by applicable law or agreed to in writing,
software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, either express or implied. See the License for the specific language governing permissions and limitations
under the License.

'''
from setuptools import setup, find_packages

NAME = "multi-platform"
VERSION = "0.2.1"
# AUTHOR = "haleli"
AUTHOR = "pengfeeli"
PACKAGES = find_packages()
CLASSIFIERS = [
    "Operating System :: Microsoft :: Windows",
    "Operating System :: MacOS",
    "Operating System :: Unix",
    "Programming Language :: Python :: 2.7",
]

setup(
    name=NAME,
    version=VERSION,
    author=AUTHOR,
    packages=PACKAGES,
    classifiers=CLASSIFIERS,
    include_package_data=True,
    install_requires=[]
)



# -*- coding: UTF-8 -*-

'''Ke App类
'''

import time
from qt4a.androidapp import AndroidApp
from testbase.conf import settings


class OEDApp(AndroidApp):
    '''
    OEDApp for Android基类
    '''
    package_name = settings.PACKAGE_NAME
    start_activity = settings.START_ACTIVITY

    def __init__(self, device, kill_process=True, start_activity=True, clear_data=True, choose_user_guide=False):
        super(OEDApp, self).__init__(self.__class__.package_name, device)

        if settings.DEBUG:
            kill_process = False
            start_activity = False
            clear_data = False

        self.re_install = True
        self.choose_user_guide = choose_user_guide

        # 辅导的debug包也进行了控件Id混淆
        if hasattr(settings, 'QT4A_USE_INT_VIEW_ID') and settings.QT4A_USE_INT_VIEW_ID:
            self._use_int_view_id = True
        else:
            pass

        if kill_process:
            self._device.kill_process(self.__class__.package_name)

        if clear_data:
            self._device.clear_data(self.__class__.package_name)
        else:
            self.re_install = False

        self.grant_all_runtime_permissions()

        if start_activity:
            self.start()

    def start(self):
        '''启动应用
        '''
        self._device.start_activity(self.__class__.package_name + '/' + self.__class__.start_activity)
        time.sleep(3)

    def swipe_screen(self, x1, y1, x2, y2, count=1):
        '''自由滑动屏幕
        :param x1， y1: 滑动点起点位置（屏幕百分比 0-1）
        :param x2, y2: 滑动点终点位置（屏幕百分比 0-1）
        :param count:     次数
        '''
        width, height = self.device.screen_size
        x1, y1 = width * x1, height * y1
        x2, y2 = width * x2, height * y2
        for _ in range(count):
            self.get_driver().drag(x1, y1, x2, y2)
            time.sleep(0.5)

    def swipe_screen_oriented(self, x, y, direction, count=1):
        '''沿固定方向滑动屏幕
        :param x， y: 滑动点起点位置（屏幕百分比 0-1）
        :param direction: 滑动方向 (left, right, top, bottom)
        :param count:     次数
        '''
        width, height = self.device.screen_size
        x1, y1 = width * x, height * y
        x2, y2 = x1, y1
        if direction == 'right':
            x2 += width
        elif direction == 'left':
            x2 -= width
        elif direction == 'top':
            y2 -= height
        elif direction == 'bottom':
            y2 += height
        else:
            raise RuntimeError('不支持的方向：%s' % direction)
        for _ in range(count):
            self.get_driver().drag(x1, y1, x2, y2)
            time.sleep(0.5)

    def swipe_pagedown(self, count=1):
        '''滑动屏幕至下一页
        :param count:     次数
        :type  count:     int
        '''
        width, height = self.device.screen_size
        x1, y1 = width // 2, height // 2
        x2, y2 = x1, y1
        y2 = y1 - int(height)
        for _ in range(count):
            self.get_driver().drag(x1, y1, x2, y2)
            time.sleep(1)

    def write_text(self, text):
        self.device.send_text(text)

    def swipe_pageup(self, count=1):
        '''滑动屏幕至下一页
        :param count:     次数
        :type  count:     int
        '''
        width, height = self.device.screen_size
        x1, y1 = width // 2, height // 2
        x2, y2 = x1, y1
        y2 = y1 + int(height)
        for _ in range(count):
            self.get_driver().drag(x1, y1, x2, y2)
            time.sleep(0.5)



# -*- coding: UTF-8 -*-

'''跨平台Device类
'''


class Device(object):
    '''
    '''

    def __init__(self, device):
        self._device = device

    def get_device(self):
        return self._device
